Changelog
=========

0.8.1 (2025-05-04)
------------------
- Setup (dependencies) update.

0.8.0 (2025-04-28)
------------------
- Add support for Python 3.14
- Drop support for Python 3.9 (due to compatibility issues).
- Update readthedocs's python to version 3.13
- Update tox's base_python to version 3.13
- Setup (dependencies) update.

0.7.0 (2025-04-27)
------------------
- 100% code linting.
- Add support for PyPy 3.10 and 3.11
- Add/improve support for Python >= 3.9, <= 3.13
- Drop support for Python <= 3.8
- Drop support for Python 2.
- Copyright year update.
- | Tox configuration is now in native (toml) format (as part of
  | pyproject.toml) and now based on tox >= 4.0.
- Setup update. Currently based on pyproject.toml.
- Source distribution (\*.tar.gz now) is compliant with PEP-0625.
- Creating a fork of Alex Sherman's *deco* package with a fix allowing
  to work with Python3 or higher and newest versions of pip/setuptools.
- Minor improvements and cleanup..

Above are changes of the original (v.0.6.3) *deco*:

0.6.3 (2025-04-24)
------------------
- Initial commit.
